/*
** File: derror.c  
** Project: ADMXRC3 API module library
** Purpose: OS-independent code for ADMXRC3 API module library
**
** (C) Copyright Alpha Data 2012
**
** Implements the device error handling functions.
*/

#include <admxrc3.h>
#include <admxrc3_platform.h>
#include "ioctl_admxrc3.h"

ADMXRC3_EXPORT ADMXRC3_STATUS
ADMXRC3_CALLING_CONVENTION
ADMXRC3_ClearDeviceErrors(
  ADMXRC3_HANDLE hCard)
{
  return admxrc3Ioctl(hCard, ADMXRC3_IOCTLCODE_CLEARDEVICEERRORS, NULL, 0, 0);
}

ADMXRC3_EXPORT ADMXRC3_STATUS
ADMXRC3_CALLING_CONVENTION
ADMXRC3_GetDeviceStatus(
  ADMXRC3_HANDLE hCard,
  _ADMXRC3_UINT32 flags,
  ADMXRC3_DEVICE_STATUS* pDeviceStatus,
  _ADMXRC3_BOOL* pbAnyError)
{
  IOCTLS_ADMXRC3_GETDEVICESTATUS ioctl;
  ADMXRC3_STATUS status;

  if (NULL == pDeviceStatus) {
    return ADMXRC3_NULL_POINTER;
  }

  ioctl.in.flags = flags;
  status = admxrc3Ioctl(hCard, ADMXRC3_IOCTLCODE_GETDEVICESTATUS, &ioctl, sizeof(ioctl.in), sizeof(ioctl.out));
  if (ADMXRC3_SUCCESS == status) {
    memset(pDeviceStatus, 0, sizeof(*pDeviceStatus));
    pDeviceStatus->Window = ioctl.out.window;
    pDeviceStatus->DMA = ioctl.out.dma;
    pDeviceStatus->DirectMaster = ioctl.out.directMaster;
    pDeviceStatus->ModelLow = ioctl.out.modelLow;
    pDeviceStatus->ModelHigh = ioctl.out.modelHigh;
    if (NULL != pbAnyError) {
      *pbAnyError = (ioctl.out.window || ioctl.out.dma || ioctl.out.directMaster || ioctl.out.modelLow || ioctl.out.modelHigh) ? TRUE : FALSE;
    }
  }
  return status;
}
