/*
** File: model_admxrc7z1.c
** Project: ADMXRC3 module driver
** Purpose: ADM-XRC-7Z1/-7Z2 specific code, including the function to bootstrap
**          the device context.
**
** (C) Copyright Alpha Data 2014
*/

#include <df.h>

#include "device.h"
#include "info.h"
#include "model_boot.h"
#include <core/admxrc7z1.h>

static ADMXRC3_STATUS
getBankInfo(
	Admxrc3DeviceContext* pDevCtx,
  unsigned int bankIndex,
  const void* pVpdBuffer,
  IOCTLS_ADMXRC3_GETBANKINFO* pIoctl)
{
  return ADMXRC3_INVALID_INDEX;
}

static void
getCardInfo(
	Admxrc3DeviceContext* pDevCtx,
  const void* pVpdBuffer,
  IOCTLS_ADMXRC3_GETCARDINFO* pIoctl)
{
  pIoctl->out.serialNumber = 0;
  pIoctl->out.numMemoryBank = 0;
  pIoctl->out.memoryBankPresent = 0;

  /* Override these fields */
  pIoctl->out.model = CoreModelGeneric;
  pIoctl->out.numTargetFpga = 0;
}

static ADMXRC3_STATUS
getFpgaInfo(
	Admxrc3DeviceContext* pDevCtx,
  unsigned int targetIndex,
  const void* pVpdBuffer,
  IOCTLS_ADMXRC3_GETFPGAINFO* pIoctl)
{
  return ADMXRC3_INVALID_INDEX;
}

static void
bootstrap(
	Admxrc3DeviceContext* pDevCtx)
{
  pDevCtx->methods.pGetBankInfo = getBankInfo;
  pDevCtx->methods.pGetCardInfo = getCardInfo;
  pDevCtx->methods.pGetFpgaInfo = getFpgaInfo;
  pDevCtx->bReverseSelectMapData = FALSE;
  pDevCtx->localAddressLimit = (uint64_t)(0x1ULL << 39U);
  pDevCtx->localWidth = 16U;
}

void
admxrc3BootstrapAdmxrc7z1(
	Admxrc3DeviceContext* pDevCtx)
{
  dfDebugPrint(1, ("admxrc3BootstrapAdmxrc7z1: entered\n"));
  bootstrap(pDevCtx);
}

void
admxrc3BootstrapAdmxrc7z2(
	Admxrc3DeviceContext* pDevCtx)
{
  dfDebugPrint(1, ("admxrc3BootstrapAdmxrc7z2: entered\n"));
  bootstrap(pDevCtx);
}
